##  Configuring Mapping of Relations
The configuration process is similar for all relations, and this guide considers the relApplicationToDataObject relation for illustration.
Relation mapping can be achieved through either of the following strategies:
  * Simple Relation: In this strategy, a simple relation is created on application assets in Collibra.
  * Complex Relation: In this strategy, complex relations are created on application assets in Collibra.
  * Intermediate Asset: In this strategy, an intermediate asset is created in Collibra for every relation on applications.
